import Link from "next/link"
import { ArrowLeft, BookOpen, ChevronRight } from "lucide-react"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import NavBar from "@/components/nav-bar"

const lessons = [
  {
    id: "1",
    title: "La signalisation routière",
    description: "Apprenez à reconnaître et comprendre les différents panneaux et signaux routiers.",
    topics: ["Panneaux de danger", "Panneaux d'interdiction", "Panneaux d'obligation", "Feux tricolores"],
    color: "blue",
  },
  {
    id: "2",
    title: "Les règles de priorité",
    description: "Maîtrisez les règles de priorité dans différentes situations de circulation.",
    topics: ["Priorité à droite", "Carrefours à sens giratoire", "Intersections", "Véhicules prioritaires"],
    color: "red",
  },
  {
    id: "3",
    title: "La vitesse et les distances de sécurité",
    description: "Comprenez l'importance de la vitesse et des distances de sécurité pour une conduite responsable.",
    topics: ["Limitations de vitesse", "Distances d'arrêt", "Distances de sécurité", "Adaptation de la vitesse"],
    color: "yellow",
  },
  {
    id: "4",
    title: "L'alcool, les drogues et la conduite",
    description: "Informez-vous sur les effets de l'alcool et des drogues sur la conduite et les sanctions encourues.",
    topics: ["Effets sur le comportement", "Taux d'alcoolémie", "Dépistage", "Sanctions"],
    color: "red",
  },
  {
    id: "5",
    title: "Les règles de stationnement",
    description: "Découvrez les différentes règles de stationnement et d'arrêt en agglomération et hors agglomération.",
    topics: ["Stationnement interdit", "Stationnement dangereux", "Stationnement gênant", "Zones bleues"],
    color: "blue",
  },
  {
    id: "6",
    title: "La conduite écologique",
    description:
      "Apprenez les techniques de l'éco-conduite pour réduire votre consommation et votre impact environnemental.",
    topics: ["Anticipation", "Changement de vitesse", "Entretien du véhicule", "Économie de carburant"],
    color: "green",
  },
]

export default function LessonsPage() {
  return (
    <div className="min-h-screen route-pattern">
      <NavBar />

      {/* Reste du contenu de la page */}
      <div className="route-header bg-white py-4 shadow-md mb-8">
        <div className="container mx-auto px-4">
          <h1 className="text-3xl font-bold text-center text-route-blue">Leçons du Code de la Route</h1>
          <div className="flex justify-center mt-2">
            <div className="road-line w-32"></div>
          </div>
        </div>
      </div>

      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Link href="/" className="inline-flex items-center text-route-blue mb-6">
          <ArrowLeft className="mr-2 h-4 w-4" />
          Retour à l'accueil
        </Link>

        <div className="mb-8">
          <p className="text-lg text-muted-foreground">
            Consultez nos leçons détaillées pour maîtriser les règles du code de la route.
          </p>
        </div>

        <div className="space-y-6">
          {lessons.map((lesson) => (
            <Card key={lesson.id} className={`hover:shadow-md transition-shadow route-card route-card-${lesson.color}`}>
              <CardHeader>
                <div className="flex items-start justify-between">
                  <div>
                    <CardTitle className="text-xl flex items-center">
                      <BookOpen className={`h-5 w-5 mr-2 text-route-${lesson.color}`} />
                      {lesson.title}
                    </CardTitle>
                    <CardDescription className="mt-2">{lesson.description}</CardDescription>
                  </div>
                  <Link href={`/lessons/${lesson.id}`}>
                    <div className={`p-2 rounded-full hover:bg-route-${lesson.color}/10 text-route-${lesson.color}`}>
                      <ChevronRight className="h-5 w-5" />
                    </div>
                  </Link>
                </div>
              </CardHeader>
              <CardContent>
                <h3 className="text-sm font-medium text-muted-foreground mb-2">Sujets abordés :</h3>
                <div className="flex flex-wrap gap-2">
                  {lesson.topics.map((topic, index) => (
                    <div
                      key={index}
                      className={`bg-route-${lesson.color}/10 text-route-${lesson.color} text-sm px-3 py-1 rounded-full`}
                    >
                      {topic}
                    </div>
                  ))}
                </div>
              </CardContent>
            </Card>
          ))}
        </div>
      </div>
    </div>
  )
}
